#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ACSCD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ACSCD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/scalar/acscd.hpp>

#endif
